PyBaccarat: tests.test_card.TestCard Class Reference

PyBaccarat visit the ministry of silly walks

Public Member Functions | List of all members
tests.test_card.TestCard Class Reference
Inheritance diagram for tests.test_card.TestCard:

## Public Member Functions
def | test_constructor (self)
def | test_getrank (self)
def | test_getsuit (self)
def | test_ordinal (self)
def | test_tostring (self)
def | test_eq (self)
def | test_ne (self)
| test ne method
def | test_lt (self)
def | test_le (self)
def | test_gt (self)
def | test_ge (self)
def | test_hash (self)
def | test_inherit (self)

## Detailed Description

    Unit test for the Card class.

## Member Function Documentation

## ◆ test_constructor()

def tests.test_card.TestCard.test_constructor | ( |  | self | ) |

    test card construction

## ◆ test_eq()

def tests.test_card.TestCard.test_eq | ( |  | self | ) |

    test __eq__ method

## ◆ test_ge()

def tests.test_card.TestCard.test_ge | ( |  | self | ) |

    __ge__

## ◆ test_getrank()

def tests.test_card.TestCard.test_getrank | ( |  | self | ) |

    test get_rank method

## ◆ test_getsuit()

def tests.test_card.TestCard.test_getsuit | ( |  | self | ) |

    test get_suit method

## ◆ test_gt()

def tests.test_card.TestCard.test_gt | ( |  | self | ) |

    __gt__

## ◆ test_hash()

def tests.test_card.TestCard.test_hash | ( |  | self | ) |

    __hash__

## ◆ test_inherit()

def tests.test_card.TestCard.test_inherit | ( |  | self | ) |

    inheritted things from object:

    c = playingcards.Card(5,'s')
    dir(c)
    ['__delattr__', '__getattribute__', '__setattr__', '__new__',
    '__dict__', '__dir__', '__format__', '__init_subclass__',
    '__subclasshook__', '__reduce__', '__reduce_ex__', '__weakref__']

    @todo inherit tests

## ◆ test_le()

def tests.test_card.TestCard.test_le | ( |  | self | ) |

    __le__

## ◆ test_lt()

def tests.test_card.TestCard.test_lt | ( |  | self | ) |

    __lt__

## ◆ test_ordinal()

def tests.test_card.TestCard.test_ordinal | ( |  | self | ) |

    test ordinal method

## ◆ test_tostring()

def tests.test_card.TestCard.test_tostring | ( |  | self | ) |

    test __str__ method

The documentation for this class was generated from the following file:

- tests/test_card.py